@@ -256,7 +256,7 @@ class Screen(SignalEvent):
                 self.clear()
                 self.context_screen.display(set_cursor=True)
                 return False
-            context = self.context
+            context = self.group._context.copy()
             context.update(self.context_screen.get_on_change_value())
             self.new_group(context)
 
@@ -307,6 +307,7 @@ class Screen(SignalEvent):
                 domain = self.domain_parser.parse(search_string)
             else:
                 domain = self.search_value
+                self.search_value = None
             if set_text:
                 self.screen_container.set_text(
                     self.domain_parser.string(domain))
@@ -428,8 +429,8 @@ class Screen(SignalEvent):
                 # XXX offset?
                 pos = record.get_index_path()
         else:
-            pos = None
-        self.signal('record-message', (pos or 0, len(self.group) + self.offset,
+            pos = 0
+        self.signal('record-message', (pos, len(self.group) + self.offset,
             self.search_count, record and record.id))
         attachment_count = 0
         if record and record.attachment_count > 0:
@@ -1217,8 +1218,11 @@ class Screen(SignalEvent):
         path = [CONFIG['login.db'], 'model', self.model_name]
         view_ids = [v.view_id for v in self.views] + self.view_ids
         if self.current_view.view_type != 'form':
-            search_string = self.screen_container.get_text()
-            search_value = self.domain_parser.parse(search_string)
+            if self.search_value:
+                search_value = self.search_value
+            else:
+                search_string = self.screen_container.get_text()
+                search_value = self.domain_parser.parse(search_string)
             if search_value:
                 query_string.append(('search_value', json.dumps(
                             search_value, cls=JSONEncoder,
