@@ -143,7 +143,8 @@ class AdaptModelGroup(gtk.GenericTreeModel):
     def sort(self, ids):
         old_idx = {record.id: i for i, record in enumerate(self.group)}
         new_idx = {id_: i for i, id_ in enumerate(ids)}
-        self.group.sort(key=lambda r: new_idx.get(r.id))
+        size = len(self.group)
+        self.group.sort(key=lambda r: new_idx.get(r.id, size))
         new_order = []
         prev = None
         for record in self.group:
@@ -341,7 +342,7 @@ class ViewTree(View):
         widget = Widget(self, node_attrs)
         self.widgets[name].append(widget)
 
-        column = gtk.TreeViewColumn(field.attrs['string'])
+        column = gtk.TreeViewColumn(node_attrs['string'])
         column._type = 'field'
         column.name = name
 
@@ -514,10 +515,7 @@ class ViewTree(View):
     def add_sum(self, attributes):
         if 'sum' not in attributes:
             return
-        if gtk.widget_get_default_direction() == gtk.TEXT_DIR_RTL:
-            text = _(':') + attributes['sum']
-        else:
-            text = attributes['sum'] + _(':')
+        text = attributes['sum'] + _(':')
         label, sum_ = gtk.Label(text), gtk.Label()
 
         hbox = gtk.HBox()
@@ -810,6 +808,9 @@ class ViewTree(View):
             gtk.gdk.drop_finish(context, False, etime)
         else:
             context.drop_finish(False, etime)
+        selection = self.treeview.get_selection()
+        selection.unselect_all()
+        selection.select_path(record.get_index_path(model.group))
         if self.attributes.get('sequence'):
             record.group.set_sequence(field=self.attributes['sequence'])
         return True
